@@ -11,15 +11,15 @@ from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Pango
 
+from komikku.consts import COVER_WIDTH
+from komikku.consts import MISSING_IMG_RESOURCE_PATH
 from komikku.card.categories_list import CategoriesList
 from komikku.card.chapters_list import ChaptersList
 from komikku.card.tracking import TrackingDialog
 from komikku.models import Settings
-from komikku.utils import COVER_WIDTH
 from komikku.utils import CoverPicture
 from komikku.utils import folder_size
 from komikku.utils import html_escape
-from komikku.utils import MISSING_IMG_RESOURCE_PATH
 
 
 @Gtk.Template.from_resource('/info/febvre/Komikku/ui/card.ui')
@@ -265,6 +265,9 @@ class CardPage(Adw.NavigationPage):
         self.filters_dialog.present(self.window)
 
     def on_gesture_drag_end(self, _controller, _offset_x, _offset_y):
+        self.stack.set_opacity(1)
+        self.stack.remove_css_class('grayscale')
+
         if not self.pool_to_update:
             return
 
@@ -292,6 +295,9 @@ class CardPage(Adw.NavigationPage):
         if scroll_value != 0 or offset_y < 0 or self.selection_mode or start_x < 32 or start_y > self.get_height() / 3:
             return
 
+        self.stack.set_opacity(0.5)
+        self.stack.add_css_class('grayscale')
+
         self.pool_to_update_offset = offset_y
 
         if not self.pool_to_update:
@@ -329,22 +335,20 @@ class CardPage(Adw.NavigationPage):
         if (self.window.page == self.props.tag or self.window.previous_page == self.props.tag) and self.manga.id == manga.id:
             self.manga = manga
 
-    def on_manga_updated(self, _updater, manga, result):
+    def on_manga_updated(self, _updater, manga, chapters_changes, synced):
         if (self.window.page == self.props.tag or self.window.previous_page == self.props.tag) and self.manga.id == manga.id:
             self.manga = manga
 
-            if manga.server.sync:
-                self.window.add_notification(_('Read progress synchronization with server completed successfully'))
-
-            if result['nb_recent_chapters'] > 0 or result['nb_deleted_chapters'] > 0 or result['synced']:
-                if self.chapters_list.populate():
-                    self.toggle_resume(True)
-                else:
-                    self.toggle_resume(False)
-
             self.info_box.populate()
             self.toggle_filters_button()
 
+            if sum(chapters_changes.values()) > 0:
+                self.chapters_list.populate()
+                self.refresh(unread_chapters=True)
+
+            if synced:
+                self.window.add_notification(_('Read progress synchronization with server completed successfully'))
+
     def on_open_in_browser_menu_clicked(self, _action, _gparam):
         if uri := self.manga.server.get_manga_url(self.manga.slug, self.manga.url):
             Gtk.UriLauncher.new(uri=uri).launch()
@@ -402,18 +406,16 @@ class CardPage(Adw.NavigationPage):
     def populate(self):
         self.chapters_list.set_sort_order(invalidate=False)
 
-        if self.chapters_list.populate():
-            self.toggle_resume(True)
-        else:
-            self.toggle_resume(False)
-
+        self.chapters_list.populate()
         self.categories_list.populate()
 
     def refresh(self, unread_chapters=False, info=False, chapters=None):
         if unread_chapters:
             self.set_unread_chapters_badge()
+
         if info:
             self.info_box.refresh()
+
         if chapters is not None:
             self.chapters_list.refresh(chapters)
 
@@ -636,7 +638,13 @@ class InfoBox:
 
         self.set_disk_usage()
 
-        self.synopsis_label.set_markup(html_escape(manga.synopsis) if manga.synopsis else '-')
+        self.synopsis_label.set_markup('-')
+        if manga.synopsis:
+            synopsis = manga.synopsis
+            if manga.server.donate_url:
+                synopsis = f'{synopsis}\n\n<a href="{manga.server.donate_url}">{_("Donate")}</a>'
+
+            self.synopsis_label.set_markup(synopsis)  # can failed with a warning: parsing markup error
 
     def refresh(self):
         self.set_disk_usage()
