@@ -13,14 +13,14 @@ from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Pango
 
-from komikku.servers import DOWNLOAD_MAX_DELAY
+from komikku.consts import COVER_HEIGHT
+from komikku.consts import COVER_WIDTH
+from komikku.consts import DOWNLOAD_MAX_DELAY
+from komikku.consts import LOGO_SIZE
+from komikku.consts import MISSING_IMG_RESOURCE_PATH
 from komikku.utils import convert_and_resize_image
 from komikku.utils import CoverPicture
 from komikku.utils import html_escape
-from komikku.utils import COVER_HEIGHT
-from komikku.utils import COVER_WIDTH
-from komikku.utils import LOGO_SIZE
-from komikku.utils import MISSING_IMG_RESOURCE_PATH
 
 THUMB_WIDTH = 96
 THUMB_HEIGHT = 136
