@@ -10,7 +10,6 @@ import json
 import logging
 import os
 from pathlib import Path
-import re
 import shutil
 import time
 
@@ -19,6 +18,8 @@ from PIL import Image
 from PIL import ImageFilter
 from PIL import ImageStat
 
+from komikku.consts import COVER_HEIGHT
+from komikku.consts import COVER_WIDTH
 from komikku.models.database import create_db_connection
 from komikku.models.database import insert_row
 from komikku.models.database import update_row
@@ -26,11 +27,10 @@ from komikku.models.database import update_rows
 from komikku.servers.utils import get_server_class_name_by_id
 from komikku.servers.utils import get_server_dir_name_by_id
 from komikku.servers.utils import get_server_module_name_by_id
-from komikku.utils import COVER_HEIGHT
-from komikku.utils import COVER_WIDTH
 from komikku.utils import get_cached_data_dir
 from komikku.utils import get_data_dir
 from komikku.utils import is_number
+from komikku.utils import markdown_to_markup
 from komikku.utils import remove_number_leading_zero
 from komikku.utils import trunc_filename
 
@@ -82,6 +82,9 @@ class Manga:
             data.pop(key, None)
             continue
 
+        if data.get('synopsis'):
+            data['synopsis'] = markdown_to_markup(data['synopsis'])
+
         # Fill data with internal data
         data.update(dict(
             in_library=0,
@@ -605,12 +608,7 @@ class Manga:
 
             # Convert synopsis Markdown links (if any) into HTML <a> tags
             if data.get('synopsis'):
-                data['synopsis'] = re.sub(
-                    r'\[([^\[\]]*)\]\((.*?)\)',
-                    r'<a href="\g<2>">\g<1></a>',
-                    data['synopsis'],
-                    flags=re.M
-                )
+                data['synopsis'] = markdown_to_markup(data['synopsis'])
 
             # Clear cache
             self._chapters = None
