@@ -1,9 +1,8 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 from gettext import gettext as _
-import os
 import shutil
 
 from gi.repository import Adw
@@ -17,7 +16,6 @@ from komikku.reader.controls import Controls
 from komikku.reader.pager import Pager
 from komikku.reader.pager.webtoon import WebtoonPager
 from komikku.utils import get_file_mime_type
-from komikku.utils import is_flatpak
 
 
 @Gtk.Template.from_resource('/info/febvre/Komikku/ui/reader.ui')
@@ -70,6 +68,9 @@ class ReaderPage(Adw.NavigationPage):
         # Controls
         self.controls = Controls(self)
 
+        # Settings dialog
+        self.settings_dialog = SettingsDialog(self)
+
         self.window.navigationview.add(self)
 
     @property
@@ -181,6 +182,11 @@ class ReaderPage(Adw.NavigationPage):
         self.save_page_action.connect('activate', self.save_page)
         self.window.application.add_action(self.save_page_action)
 
+        # Open settings dialog
+        self.open_settings_dialog_action = Gio.SimpleAction.new('reader.open-settings-dialog', None)
+        self.open_settings_dialog_action.connect('activate', self.open_settings_dialog)
+        self.window.application.add_action(self.open_settings_dialog_action)
+
     def init(self, manga, chapter):
         self.manga = manga
         self.init_chapter = chapter
@@ -204,6 +210,9 @@ class ReaderPage(Adw.NavigationPage):
         self.show()
 
     def init_pager(self, chapter):
+        if self.pager:
+            self.pager.dispose()
+
         if self.reading_mode == 'webtoon':
             self.pager = WebtoonPager(self)
         else:
@@ -257,7 +266,7 @@ class ReaderPage(Adw.NavigationPage):
             if self.chapters_consulted:
                 # Refresh to update all previously chapters consulted (last page read may have changed also)
                 # and update info like disk usage
-                self.window.card.refresh(self.chapters_consulted)
+                self.window.card.refresh(unread_chapters=True, info=True, chapters=self.chapters_consulted)
 
         # Sync History page
         if self.window.history in self.window.navigationview.get_navigation_stack():
@@ -349,6 +358,9 @@ class ReaderPage(Adw.NavigationPage):
         else:
             do_init_pager()
 
+    def open_settings_dialog(self, _action, _gparam):
+        self.settings_dialog.present(self.window)
+
     def save_page(self, _action, _gparam):
         if self.window.page != self.props.tag:
             return
@@ -358,8 +370,12 @@ class ReaderPage(Adw.NavigationPage):
             return
 
         def do_save(dest_path):
-            shutil.copy(page.path, dest_path)
-            self.window.add_notification(_('Page successfully saved to {0}').format(dest_path.replace(os.path.expanduser('~'), '~')))
+            try:
+                shutil.copy(page.path, dest_path)
+            except Exception as error:
+                self.window.add_notification(str(error))
+            else:
+                self.window.add_notification(_('Page successfully saved'))
 
         def on_ready(dialog, result):
             try:
@@ -375,18 +391,12 @@ class ReaderPage(Adw.NavigationPage):
         filename = f'{self.manga.name}_{page.chapter.title}_{str(page.index + 1)}.{extension}'
         xdg_pictures_dir = GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_PICTURES)
 
-        if not is_flatpak():
-            dialog = Gtk.FileDialog(modal=True)
-            dialog.set_initial_name(filename)
-            if xdg_pictures_dir is not None:
-                dialog.set_initial_folder(Gio.File.new_for_path(xdg_pictures_dir))
+        dialog = Gtk.FileDialog(modal=True)
+        dialog.set_initial_name(filename)
+        if xdg_pictures_dir is not None:
+            dialog.set_initial_folder(Gio.File.new_for_path(xdg_pictures_dir))
 
-            dialog.save(self.window, None, on_ready)
-        else:
-            if xdg_pictures_dir is not None:
-                do_save(os.path.join(xdg_pictures_dir, filename))
-            else:
-                self.window.add_notification(_('Failed to save page: missing permission to access the XDG pictures directory'))
+        dialog.save(self.window, None, on_ready)
 
     def set_action_background_color(self):
         self.background_color_action.set_state(GLib.Variant('s', self.background_color))
@@ -475,3 +485,117 @@ class ReaderPage(Adw.NavigationPage):
         if chapter.manga.name in subtitle:
             subtitle = subtitle.replace(chapter.manga.name, '').strip()
         self.title.set_subtitle(subtitle)
+
+
+class SettingsDialog(Adw.PreferencesDialog):
+    def __init__(self, page):
+        super().__init__()
+        self.page = page
+        self.settings = Settings.get_default()
+
+        self.set_title(_('Settings'))
+        self.set_presentation_mode(Adw.DialogPresentationMode.BOTTOM_SHEET)
+
+        self.css_provider = Gtk.CssProvider.new()
+        Gtk.StyleContext.add_provider_for_display(Gdk.Display.get_default(), self.css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+
+        page = Adw.PreferencesPage(title=_('Filters'))
+        self.add(page)
+
+        group = Adw.PreferencesGroup(title=_('Filters'), separate_rows=True)
+
+        filters = {
+            'brightness': {
+                'title': _('Brightness'),
+                'subtitle': _('Make pages brighter or darker'),
+                'min': 0,
+                'max': 200,
+                'step': 1,
+                'default': 100,
+            },
+            'contrast': {
+                'title': _('Contrast'),
+                'subtitle': _('Increase or decrease the contrast of pages'),
+                'min': 0,
+                'max': 200,
+                'step': 1,
+                'default': 100,
+            },
+            'grayscale': {
+                'title': _('Grayscale'),
+                'subtitle': _('Convert pages to grayscale'),
+                'min': 0,
+                'max': 100,
+                'step': 1,
+                'default': 0,
+            },
+            'sepia': {
+                'title': _('Sepia'),
+                'subtitle': _('Give a more yellow/brown appearance to pages'),
+                'min': 0,
+                'max': 100,
+                'step': 1,
+                'default': 0,
+            },
+            'saturate': {
+                'title': _('Saturation'),
+                'subtitle': _('Super-saturate or desaturate pages'),
+                'min': 0,
+                'max': 400,
+                'step': 1,
+                'default': 100,
+            },
+        }
+
+        for name, data in filters.items():
+            erow = Adw.ExpanderRow()
+            erow.set_title(data['title'])
+            erow.set_subtitle(data['subtitle'])
+            erow.set_enable_expansion(self.settings.page_filters.get(f'{name}-state'))
+            erow.set_show_enable_switch(True)
+            erow.connect('notify::enable-expansion', self.toggle_filter_state, name)
+
+            row = Adw.SpinRow.new_with_range(data['min'], data['max'], data['step'])
+            row.set_title(data['title'])
+            row.set_value(self.settings.page_filters.get(name, data['default']))
+            row.connect('notify::value', self.set_filter_value, name)
+
+            erow.add_row(row)
+            group.add(erow)
+
+        page.add(group)
+
+        self.apply_filters()
+
+    def apply_filters(self):
+        funcs = []
+        for name, value in self.settings.page_filters.items():
+            if name.endswith('-state'):
+                # Ignore state key
+                continue
+            if not self.settings.page_filters.get(f'{name}-state'):
+                # Filter is off
+                continue
+
+            funcs.append(f'{name}({value}%)')
+
+        if funcs:
+            self.css_provider.load_from_string(f'.page-filters {{filter: {" ".join(funcs)};}}')  # noqa
+            self.page.overlay.add_css_class('page-filters')
+        else:
+            self.css_provider.load_from_string('')
+            self.page.overlay.remove_css_class('page-filters')
+
+    def set_filter_value(self, row, _gparam, name):
+        filters = self.settings.page_filters
+        filters[name] = row.get_value()
+        self.settings.page_filters = filters
+
+        self.apply_filters()
+
+    def toggle_filter_state(self, row, _gparam, name):
+        filters = self.settings.page_filters
+        filters[f'{name}-state'] = row.get_enable_expansion()
+        self.settings.page_filters = filters
+
+        self.apply_filters()
