@@ -2,12 +2,13 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
-from bs4 import BeautifulSoup
-import requests
 import textwrap
 
+from bs4 import BeautifulSoup
+import requests
+
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.servers.utils import TextImage
 from komikku.utils import get_buffer_mime_type
@@ -22,6 +23,7 @@ class Grisebouille(Server):
     long_strip_genres = ['Long Strip', ]
 
     base_url = 'https://grisebouille.net'
+    donate_url = 'https://ptilouk.net/#soutien'
     logo_url = base_url + '/content/img/favicon-32x32.png'
     search_url = base_url + '/categories.html'
     manga_url = base_url + '/category/{0}/'
