@@ -16,12 +16,52 @@ class Mangacrab(Madara2):
     date_format = '%d/%m/%Y'
     series_name = 'series'
 
-    base_url = 'https://mangacrab2.yopres.com'
-    logo_url = base_url + '/wp-content/uploads/2024/07/cropped-cropped-logo99-Personalizado-e1722469564886-32x32.png'
+    base_url = 'https://mangacrab.topmanhuas.org'
+    logo_url = base_url + '/wp-content/uploads/2017/10/cropped-logo100-Personalizado-32x32.png'
+    chapters_url = base_url + '/series/{0}/ajax/chapters/'
 
     details_name_selector = 'h1.post-title'
     details_status_selector = '.post-content_item:-soup-contains("Estado") .summary-content'
 
+    def get_manga_chapter_data(self, manga_slug, manga_name, chapter_slug, chapter_url):
+        """
+        Returns manga chapter data by scraping chapter HTML page content
+
+        Currently, only pages are expected.
+        """
+        r = self.session_get(
+            self.chapter_url.format(manga_slug, chapter_slug),
+            headers={
+                'Referer': self.manga_url.format(manga_slug),
+            }
+        )
+        if r.status_code != 200:
+            return None
+
+        soup = BeautifulSoup(r.text, 'lxml')
+
+        data = dict(
+            pages=[],
+        )
+        index = 1
+        for img_element in soup.select('.reading-content img.wp-manga-chapter-img'):
+            image = None
+            for attr, value in img_element.attrs.items():
+                if attr.startswith('data-img-'):
+                    image = value.strip()
+                    break
+            if image is None:
+                continue
+
+            data['pages'].append(dict(
+                slug=None,
+                image=image,
+                index=index,
+            ))
+            index += 1
+
+        return data
+
     def search(self, term, nsfw, orderby=None):
         params = {
             's': term or '',
