@@ -17,7 +17,7 @@
 # Ragna Scan [ES] (Disabled)
 # Raiki Scan [ES]
 # Rawkuma [JA]
-# Raw Manga [JA]
+# Raw Manga [JA] (Disabled)
 # Rukav Inari [ES] (Disabled)
 # Ryujinmanga [ES]
 # Senpai Ediciones [ES] (Disabled)
@@ -27,14 +27,15 @@
 # Tres Daos [ES]
 # VF Scan [FR]
 
-from bs4 import BeautifulSoup
 from gettext import gettext as _
 import json
 import re
+
+from bs4 import BeautifulSoup
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.servers.utils import get_soup_element_inner_text
 from komikku.utils import get_buffer_mime_type
