@@ -16,13 +16,14 @@
 # Scan OP [FR] (Disabled)
 # ScanOnePiece [FR]
 
-from bs4 import BeautifulSoup
 import re
-import requests
 from urllib.parse import urljoin
 
+from bs4 import BeautifulSoup
+import requests
+
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.servers.utils import get_soup_element_inner_text
 from komikku.utils import get_buffer_mime_type
