@@ -7,8 +7,8 @@ import json
 from bs4 import BeautifulSoup
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.multi.heancms import extract_info_from_script
 from komikku.servers.multi.heancms import HeanCMS
 from komikku.servers.multi.genkan import GenkanInitial
@@ -21,11 +21,15 @@ class Reaperscans(HeanCMS):
     id = 'reaperscans'
     name = 'Reaper Scans'
     lang = 'en'
+    status = 'disabled'
 
     base_url = 'https://reaperscans.com'
     logo_url = base_url + '/wetried_only.png'
     api_url = 'https://api.reaperscans.com'
+    api_version = 2
+    api_chapters_url = api_url + '/chapters/{0}'
 
+    name_css_path = 'h1'
     cover_css_path = 'img[width="316"]'
     authors_css_path = 'div.flex:-soup-contains("Author") > span:last-child'
     synopsis_css_path = 'div.text-muted-foreground > div:nth-child(1)'
@@ -80,6 +84,7 @@ class Reaperscans_ar(Madara):
     id = 'reaperscans_ar'
     name = 'ريبر العربي'
     lang = 'ar'
+    status = 'disabled'
 
     series_name = 'series'
     date_format = '%Y, %d %B'
