@@ -11,23 +11,23 @@ import html
 from io import BytesIO
 import logging
 import os
+import re
 import subprocess
 import traceback
 
 import gi
 from PIL import Image
 import magic
-import pillow_heif
 import requests
 from requests.adapters import HTTPAdapter
 from requests.adapters import TimeoutSauce
 from urllib3.util.retry import Retry
 
 gi.require_version('Gdk', '4.0')
-gi.require_version('Gsk', '4.0')
-gi.require_version('Gtk', '4.0')
 gi.require_version('GdkPixbuf', '2.0')
 gi.require_version('Graphene', '1.0')
+gi.require_version('Gsk', '4.0')
+gi.require_version('Gtk', '4.0')
 
 from gi.repository import Gdk
 from gi.repository import Gio
@@ -38,19 +38,12 @@ from gi.repository import Gsk
 from gi.repository import Gtk
 from gi.repository.GdkPixbuf import PixbufAnimation
 
-COVER_WIDTH = 180
-COVER_HEIGHT = 256
-LOGO_SIZE = 32
-MISSING_IMG_RESOURCE_PATH = '/info/febvre/Komikku/images/missing_file.png'
-REQUESTS_TIMEOUT = 5
+from komikku.consts import REQUESTS_TIMEOUT
 
 logger = logging.getLogger('komikku')
-logging.getLogger("PIL.Image").propagate = False
-logging.getLogger("PIL.PngImagePlugin").propagate = False
-logging.getLogger("PIL.TiffImagePlugin").propagate = False
-
-pillow_heif.register_avif_opener()
-pillow_heif.register_heif_opener()
+logging.getLogger('PIL.Image').propagate = False
+logging.getLogger('PIL.PngImagePlugin').propagate = False
+logging.getLogger('PIL.TiffImagePlugin').propagate = False
 
 
 def check_cmdline_tool(cmd):
@@ -338,6 +331,16 @@ def log_error_traceback(e):
     return None
 
 
+def markdown_to_markup(s):
+    # Convert links into <a> tags
+    return re.sub(
+        r'\[(.*?)\]\((\S*?)\s*("(.*?)")?\)',  # 1. text, 2. url, 4. title
+        r'<a href="\g<2>">\g<1></a>',
+        s,
+        flags=re.M
+    )
+
+
 def remove_number_leading_zero(str_num):
     """Remove leading zero in a number string
 
@@ -518,7 +521,7 @@ class AsyncWorker(GObject.Object):
           RESULT turns out to be invalid, return an error dictionary
           in the form
 
-          {"AsyncWorkerError": "Gio.Task.is_valid returned False."}
+          {'AsyncWorkerError': 'Gio.Task.is_valid returned False.'}
 
         """
         value = None
@@ -526,8 +529,8 @@ class AsyncWorker(GObject.Object):
         if Gio.Task.is_valid(result, self):
             value = result.propagate_value().value
         else:
-            error = "Gio.Task.is_valid returned False."
-            value = {"AsyncWorkerError": error}
+            error = 'Gio.Task.is_valid returned False.'
+            value = {'AsyncWorkerError': error}
 
         return value
 
@@ -539,7 +542,6 @@ class BaseServer:
     headers = None
     headers_images = None
     http_client = 'requests'  # HTTP client
-    ignore_ssl_errors = False
     status = 'enabled'
 
     __sessions = {}  # to cache all existing sessions
@@ -587,10 +589,10 @@ class BaseServer:
             headers['If-None-Match'] = etag
 
         if self.session:
-            r = self.session.get(url, headers=headers, verify=not self.ignore_ssl_errors)
+            r = self.session.get(url, headers=headers)
         else:
             # Session object has not yet been instantiated (servers with login or using webview to complete challenge)
-            r = requests.get(url, headers=headers, verify=not self.ignore_ssl_errors)
+            r = requests.get(url, headers=headers)
         if not r.ok:
             return None, None, get_response_elapsed(r)
 
@@ -643,7 +645,6 @@ class BaseServer:
         return True
 
     def session_get(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = retry_session(session=self.session).get(*args, **kwargs)
         except Exception as error:
@@ -653,7 +654,6 @@ class BaseServer:
         return r
 
     def session_patch(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = self.session.patch(*args, **kwargs)
         except Exception as error:
@@ -663,7 +663,6 @@ class BaseServer:
         return r
 
     def session_post(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = self.session.post(*args, **kwargs)
         except Exception as error:
@@ -673,7 +672,6 @@ class BaseServer:
         return r
 
     def session_put(self, *args, **kwargs):
-        kwargs['verify'] = not self.ignore_ssl_errors
         try:
             r = self.session.put(*args, **kwargs)
         except Exception as error:
