@@ -29,10 +29,10 @@ from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import WebKit
 
+from komikku.consts import REQUESTS_TIMEOUT
 from komikku.servers.exceptions import ChallengerError
 from komikku.servers.utils import get_session_cookies
 from komikku.utils import get_cache_dir
-from komikku.utils import REQUESTS_TIMEOUT
 
 CF_RELOAD_MAX = 3
 DEBUG = False
@@ -71,13 +71,12 @@ class WebviewPage(Adw.NavigationPage):
         session_type = GLib.getenv('XDG_SESSION_TYPE')
         session_type = session_type.capitalize() if session_type else 'Wayland'
         custom_part = f'{session_type}; Linux {cpu_arch}'  # noqa: E702
-        self.user_agent = f'Mozilla/5.0 ({custom_part}) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/17.0 Safari/605.1.15'
+        self.user_agent = f'Mozilla/5.0 ({custom_part}) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/60.5 Safari/605.1.15'
 
         # Settings
         self.settings = WebKit.Settings.new()
         self.settings.set_enable_developer_extras(DEBUG)
         self.settings.set_enable_write_console_messages_to_stdout(DEBUG)
-        self.settings.set_enable_dns_prefetching(True)
 
         # Enable extra features
         all_feature_list = self.settings.get_all_features()
@@ -369,10 +368,7 @@ class Challenger:
         self.cf_reload_count = 0
         self.done = False
         self.error = None
-        self.load_event = None
-        self.load_event_finished_timeout = 10
-        self.load_events_monitor_id = None
-        self.load_events_monitor_ts = None
+        self.last_load_event = None
 
     def cancel(self):
         self.error = f'Challenge completion aborted: {self.server.id}'
@@ -389,48 +385,42 @@ class Challenger:
         # - No challenge found: change title to 'ready'
         # - An error occurs during challenge: change title to 'error'
         js = """
-            function check() {
-                let intervalID = setInterval(() => {
-                    if (document.getElementById('challenge-error-title')) {
-                        // CF error: Browser is outdated?
-                        document.title = 'error';
-                        clearInterval(intervalID);
-                    }
-                    else if (document.querySelector('.ray-id') || document.querySelector('style').innerText.indexOf('ray-id') > 0) {
-                        document.title = 'cf_captcha';
-                    }
-                    else if (document.querySelector('#request-info')) {
-                        document.title = 'ddg_captcha';
-                    }
-                    else if (document.querySelector('.g-recaptcha') && !document.querySelector('form .g-recaptcha')) {
-                        // Google reCAPTCHA
-                        // Not in a form to avoid false positives (login form for ex.)
-                        document.title = 're_captcha';
-                    }
-                    else if (document.querySelector('#formVerify')) {
-                        document.title = 'ayh2_captcha';
-                    }
-                    else if (document.querySelector('script[src*="challange"]')) {
-                        document.title = 'challange_captcha';
-                    }
-                    else {
-                        document.title = 'ready';
-                        clearInterval(intervalID);
-                    }
-                }, 100);
-            };
+            let intervalID = setInterval(() => {
+                if (document.readyState === 'loading') {
+                    return;
+                }
 
-            if (document.readyState === 'loading') {
-                document.addEventListener('DOMContentLoaded', check);
-            }
-            else {
-                check();
-            }
+                if (document.getElementById('challenge-error-title')) {
+                    // CF error: Browser is outdated?
+                    document.title = 'error';
+                    clearInterval(intervalID);
+                }
+                else if (document.querySelector('.main-wrapper[role="main"] .main-content') || document.querySelector('.ray-id')) {
+                    document.title = 'cf_captcha';
+                }
+                else if (document.querySelector('#request-info')) {
+                    document.title = 'ddg_captcha';
+                }
+                else if (document.querySelector('.g-recaptcha') && !document.querySelector('form .g-recaptcha')) {
+                    // Google reCAPTCHA
+                    // Not in a form to avoid false positives (login form for ex.)
+                    document.title = 're_captcha';
+                }
+                else if (document.querySelector('#formVerify')) {
+                    document.title = 'ayh2_captcha';
+                }
+                else if (document.querySelector('script[src*="challange"]')) {
+                    document.title = 'challange_captcha';
+                }
+                else {
+                    document.title = 'ready';
+                    clearInterval(intervalID);
+                }
+            }, 100);
         """
         self.webview.webkit_webview.evaluate_javascript(js, -1)
 
     def on_load_changed(self, _webkit_webview, event):
-        self.load_event = event
         logger.debug(f'Load changed: {event} {self.webview.webkit_webview.get_uri()}')
 
         if event != WebKit.LoadEvent.REDIRECTED and '__cf_chl_tk' in self.webview.webkit_webview.get_uri():
@@ -441,9 +431,15 @@ class Challenger:
             logger.debug('Disable images automatic loading')
             self.webview.webkit_webview.get_settings().set_auto_load_images(False)
 
-        elif event == WebKit.LoadEvent.COMMITTED:
+        elif event == WebKit.LoadEvent.COMMITTED or \
+                (event == WebKit.LoadEvent.FINISHED and self.last_load_event != WebKit.LoadEvent.COMMITTED):
+            # Normally, COMMITTED (2) event is received and then FINISHED (3) event.
+            # The challenge can be monitored as soon as COMMITTED event is emitted,
+            # but sometimes it isn't, so we have to wait for FINISHED event.
             self.monitor_challenge()
 
+        self.last_load_event = event
+
     def on_load_failed(self, _webkit_webview, _event, uri, _gerror):
         self.error = f'Challenge completion error: failed to load URI {uri}'
 
@@ -496,7 +492,9 @@ class Challenger:
         self.webview.exit()
 
         logger.debug(f'{self.server.id}: Page loaded, getting cookies...')
-        self.webview.network_session.get_cookie_manager().get_cookies(self.server.base_url, None, self.on_get_cookies_finished, None)
+        self.webview.network_session.get_cookie_manager().get_cookies(
+            self.url, None, self.on_get_cookies_finished, None
+        )
 
     def on_get_cookies_finished(self, cookie_manager, result, _user_data):
         if self.server.http_client == 'requests':
